clarabel: Clarabel Conic Interior Point Solver for Rust / Python
================================================================

Description
-----------

Clarabel Conic Interior Point Solver for Rust / Python

License
-------

Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/clarabel/

